==> opengtl_0.9.12.orig.tar.bz2: OpenGTL-0.9.12/OpenShiva/tests/library/TestKernelProgressReport.h <==
/*
 *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "GTLCore/ProgressReport.h"

class TestProgressReport : public GTLCore::ProgressReport {
  public:
    TestProgressReport() : m_row(0), m_pixel(0)
    {
    }
    void nextRow() { ++m_row; }
    void nextPixel() { ++m_pixel; }
    bool interrupted() const { return false; }
    int m_row, m_pixel;
};

class TestKernelProgressReport : public GTLTest::Case {
  public:
    TestKernelProgressReport() : GTLTest::Case("KernelProgressReport")
    {
    }
    virtual void runTest()
    {
      OpenShiva::Kernel k;
      k.setSource(
"kernel PlainGenerator \
{ \
  void evaluatePixel(out pixel result) \
  { \
  } \
}" );
      k.compile();
      GTLTEST_CHECK_REQUIRED(k.isCompiled());
      TestProgressReport tpr;
      GTLCore::Image img(100, 50, GTLCore::PixelDescription(GTLCore::Type::Integer8, 4));
      k.evaluatePixeles( GTLCore::Region(0,0,100,50), std::list< GTLCore::AbstractImage* >(), &img, &tpr);
      GTLTEST_CHECK_EQUAL(tpr.m_pixel, 5000);
      GTLTEST_CHECK_EQUAL(tpr.m_row, 50);
    }
};

==> opengtl_0.9.14.orig.tar.bz2: OpenGTL-0.9.14/OpenShiva/tests/library/TestKernelProgressReport.h <==
/*
 *  Copyright (c) 2009 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "GTLCore/ProgressReport.h"

class TestProgressReport : public GTLCore::ProgressReport {
  public:
    TestProgressReport() : m_row(0), m_pixel(0)
    {
    }
    void nextRow() { ++m_row; }
    void nextPixel() { ++m_pixel; }
    bool interrupted() const { return false; }
    int m_row, m_pixel;
};

class TestKernelProgressReport : public GTLTest::Case {
  public:
    TestKernelProgressReport() : GTLTest::Case("KernelProgressReport")
    {
    }
    virtual void runTest()
    {
      OpenShiva::Kernel k;
      k.setSource(
"kernel PlainGenerator \
{ \
  void evaluatePixel(out pixel result) \
  { \
  } \
}" );
      k.compile();
      GTLTEST_CHECK_REQUIRED(k.isCompiled());
      TestProgressReport tpr;
      GTLCore::Image img(100, 50, GTLCore::PixelDescription(GTLCore::Type::Integer8, 4));
      k.evaluatePixels( GTLCore::RegionI(0,0,100,50), std::list< const GTLCore::AbstractImage* >(), &img, &tpr);
      GTLTEST_CHECK_EQUAL(tpr.m_pixel, 5000);
      GTLTEST_CHECK_EQUAL(tpr.m_row, 50);
    }
};
